@@ -27,6 +27,7 @@ SNAKYPY__SSH_COLOR="{parsed['ssh']['color']}"
 SNAKYPY__SSH_PREFIX_COLOR="{parsed['ssh']['prefix']['color']}"
 SNAKYPY__PYPROJECT_COLOR="{parsed['pyproject']['color']}"
 SNAKYPY__PYPROJECT_PREFIX_COLOR="{parsed['pyproject']['prefix']['color']}"
+SNAKYPY__TIMER_COLOR={parsed['timer']['color']}
 SNAKYPY__PY_VERSION_PREFIX_TEXT="{parsed['python']['prefix']['text']}"
 SNAKYPY__VIRTUALENV_PREFIX_TEXT="{parsed['virtualenv']['prefix']['text']}"
 SNAKYPY__SSH_PREFIX_TEXT="{parsed['ssh']['prefix']['text']}"
@@ -51,6 +52,8 @@ SNAKYPY__ENABLE_HOSTNAME_USERNAME_SSH={parsed['ssh']['userhost']['enable']}
 SNAKYPY__ABSOLUTE_PATH_ENABLE={parsed['path']['abspath']['enable']}
 SNAKYPY__VIRTUALENV_NAME_NORMAL_ENABLE={parsed['virtualenv']['name']['normal']['enable']}
 SNAKYPY__PYPROJECT_ENABLE={parsed['pyproject']['enable']}
+SNAKYPY__TIMER_ENABLE={parsed['timer']['enable']}
+SNAKYPY__TIMER_SECOND_ENABLE={parsed['timer']['seconds']['enable']}
 """
     }
     return data
